@@ -25,5 +25,6 @@ dissection <- function(x, s=5, ...) {
        m <- matrix(1, nrow=s, ncol=s)
     rmin <- raster::focal(x, w=m, fun=min)
     rmax <- raster::focal(x, w=m, fun=max)
-    return( raster::calc(raster::stack(x,rmin,rmax), fun=function(x) { (x[1] - x[2] ) / ( x[3] - x[2] ) }, ... )   )
+    return( raster::calc(raster::stack(x,rmin,rmax), fun = function(x) { (x[1] - x[2] ) / 
+	        ( x[3] - x[2] ) }, ... )   )
 }  
